@@ -2,7 +2,8 @@ from urllib import parse
 import urllib
 import urllib.request
 import requests,json
-ak='PNngqzs09GAwTs0MCQqGIBvLtOe342ZU'
+ak=urllib.request.urlopen("http://www.asunc.cn/ak.txt").read().decode("utf-8")
+ak=json.loads(ak)['ak']
 def get_ipaddress(ip, getpoint=False):
     if ip.count(".") != 3:
         return -1
@@ -14,7 +15,7 @@ def get_ipaddress(ip, getpoint=False):
         else:
             address = json.loads(address)
             if address['status'] == 0:
-                if getpoint:
+                if getpoint==True:
                     content = address['content']
                     addrpoint = content['point']
                     return content['address'], addrpoint['x'], addrpoint['y']
@@ -31,4 +32,4 @@ def get_traffic(road,city):
     if address['status']==0:
         return address['description']
     else:
-        return -1
\ No newline at end of file
+        return -1
