@@ -16,7 +16,7 @@ import requests
 from urllib.request import*
 import json
 def getversion():
-    return "0.0.5"
+    return "0.4.5"
 def cleardevice():
     print("\033[2J")
     print("\033[99999999999999999999999999999999A", end='')
@@ -50,20 +50,15 @@ def getweather(province,city):
     result = r.json()
     city = result['translateResult'][0][0]["tgt"]
     try:
-        wurl="https://tianqi.moji.com/weather/china/{}/{}".format(province,city)
+        wurl="https://tianqi.moji.com/weather/china/"+province+'/'+city
         html = urllib.request.urlopen(wurl).read().decode("utf-8")
-    except:
-        return -1
-        tf=1
-    try:
         par = '(<meta name="description" content=")(.*?)(">)'
-        data = re.search(par,html).group(2)
-        data = data.replace(",","，").replace("。","，").replace("墨迹天气建议您","爱搜天气助手建议您")
+        data = re.search(par, html).group(2)
+        data = data.replace(",", "，").replace("。", "，").replace("墨迹天气建议您", "爱搜天气助手建议您")
+        return data
     except:
         return -1
-        tf=1
-    if tf!=1:
-        return data
+
 def get_news():
     now = time.strftime("%Y-%m-%d", time.localtime())
     print(now,"最新新闻资讯,转载于人民日报。\n")
@@ -151,4 +146,4 @@ def get_imformation(pid):
         unlikes=p["data"]["unlikes"]
         return likes,unlikes,p["data"]["username"],p["data"]["user_id"]
     except:
-        return -1
+        return -1
\ No newline at end of file
